@@ -38,6 +38,7 @@ def __run(
         _results.append({
             'key': getattr(getattr(provider, 'instance'), 'key'),
             'type': getattr(getattr(provider, 'instance'), 'type'),
+            'name': getattr(getattr(provider, 'instance'), 'name'),
             'response': instance_result,
         })
 
@@ -48,19 +49,22 @@ def __run(
     if post_to_api:
         if session is None:
             session = requests_session
-            session.headers.update({'Content-Type': 'application/json'})
             session.headers.update({'Authorization': f"Token {config.api_key}"})
-        r = session.post(config.dashboard_url, data=post_body)
-        if r.status_code != 200:
-            raise Exception(f'Failed to post to dashboard: {r.status_code}')
+        try:
+            r = session.post(config.dashboard_url, data=post_body)
+            if r.status_code != 200:
+                raise Exception(f'Failed to post to dashboard: {r.status_code}')
+        finally:
+            if auto_close is True:
+                session.close()
     else:
         print(post_body)
 
 
-def run(conf_file: Union[str, Path], providers: Dict[str, BaseProvider] = None, auto_close: bool = True):
+def run(conf_file: Union[str, Path], providers: Dict[str, BaseProvider] = None):
     config = types.Config.from_file(conf_file)
 
-    __run(config, providers, auto_close)
+    __run(config, providers, auto_close=True)
 
 
 def run_forever(
@@ -70,9 +74,7 @@ def run_forever(
 ):
     config = types.Config.from_file(conf_file)
 
-    session = requests_session
-    session.headers.update({'Content-Type': 'application/json'})
-    session.headers.update({'Authorization': f"Token {config.api_key}"})
+    requests_session.headers.update({'Authorization': f"Token {config.api_key}"})
 
     __scheduler.add_job(
         __run,
@@ -83,7 +85,7 @@ def run_forever(
             providers,
             False,
             True,
-            session,
+            requests_session,
         ]
     )
     __scheduler.add_listener(__job_exception_handler, EVENT_JOB_ERROR)
@@ -95,6 +97,7 @@ def run_forever(
     except (KeyboardInterrupt, SystemExit):
         print('Shutting down...')
     finally:
+        requests_session.close()
         if __scheduler.running:
             __scheduler.shutdown(wait=False)
         for provider in __inited_providers.values():
